@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: Unlicense
 
-import secrets  # pylint: disable=no-name-in-module
+import os
 
 import mdns
 import socketpool
@@ -14,7 +14,8 @@ from adafruit_httpserver.response import HTTPResponse
 from adafruit_httpserver.server import HTTPServer
 
 
-ssid, password = secrets.WIFI_SSID, secrets.WIFI_PASSWORD  # pylint: disable=no-member
+ssid = os.getenv("WIFI_SSID")
+password = os.getenv("WIFI_PASSWORD")
 
 print("Connecting to", ssid)
 wifi.radio.connect(ssid, password)
@@ -25,7 +26,7 @@ mdns_server.hostname = "custom-mdns-hostname"
 mdns_server.advertise_service(service_type="_http", protocol="_tcp", port=80)
 
 pool = socketpool.SocketPool(wifi.radio)
-server = HTTPServer(pool)
+server = HTTPServer(pool, "/static")
 
 
 @server.route("/")
